@@ -11,7 +11,6 @@
 
 //---------------------------------------------------------------------------
 #include "MediaInfo/Tag/File__Tags.h"
-#include <map>
 //---------------------------------------------------------------------------
 
 namespace MediaInfoLib
@@ -26,7 +25,6 @@ class File_Mpega : public File__Analyze, public File__Tags_Helper
 public :
     //In
     int64u Frame_Count_Valid;
-    bool   FrameIsAlwaysComplete;
     bool   CalculateDelay;
 
     //Constructor/Destructor
@@ -47,10 +45,15 @@ private :
     //Buffer - Demux
     bool Demux_UnpacketizeContainer_Test();
 
+    //Buffer - Global
+    void Read_Buffer_Unsynched();
+    void Read_Buffer_Continue();
+
     //Buffer - Per element
     void Header_Parse();
     void Data_Parse();
     void Data_Parse_Fill();
+    void audio_data_Layer3();
 
     //Element
     bool Header_Xing();
@@ -63,7 +66,7 @@ private :
     Ztring BitRate_Mode;
     Ztring BitRate_Nominal;
     Ztring BitRate_Minimum;
-    Ztring Encoded_Library;
+    string Encoded_Library;
     Ztring Encoded_Library_Settings;
     std::map<int16u, size_t> BitRate_Count;
     std::map<int8u, size_t> sampling_frequency_Count;
@@ -93,10 +96,20 @@ private :
     bool   padding_bit;
     bool   copyright;
     bool   original_home;
+    bool   VBR_Frames_IsCbr;
+    bool   LastSync_Offset_AreNotZero;
     size_t MpegPsPattern_Count;
 
     //Helpers
     bool Element_Name_IsOK();
+
+    #if MEDIAINFO_DEMUX
+        #if MEDIAINFO_ADVANCED
+            int8u sampling_frequency_Frame0;
+            int8u mode_Frame0;
+            bool  File_Demux_Unpacketize_StreamLayoutChange_Skip;
+        #endif //MEDIAINFO_ADVANCED
+    #endif //MEDIAINFO_DEMUX
 };
 
 } //NameSpace
